pub struct RetrievalHit {
pub episode_id: Uuid,
pub step_number: Option<usize>,
pub score: f32,
pub source_tier: String,
}Expand description
A single hit from retrieval that will be expanded into a window.
Fields
episode_id: UuidEpisode ID of the hit.
step_number: Option<usize>Step number within the episode (if applicable).
score: f32Relevance score of this hit.
source_tier: StringSource tier that produced this hit (bm25, hdc, etc).
Implementations
Sourceimpl RetrievalHit
impl RetrievalHit
Sourcepub fn new(episode_id: Uuid, score: f32, source_tier: String) -> Self
pub fn new(episode_id: Uuid, score: f32, source_tier: String) -> Self
Create a new retrieval hit.
Sourcepub fn with_step(
episode_id: Uuid,
step_number: usize,
score: f32,
source_tier: String,
) -> Self
pub fn with_step( episode_id: Uuid, step_number: usize, score: f32, source_tier: String, ) -> Self
Create a retrieval hit with a specific step number.
Sourcepub fn meets_threshold(&self, threshold: f32) -> bool
pub fn meets_threshold(&self, threshold: f32) -> bool
Check if this hit meets the minimum score threshold.